==> qtcreator_3.5.1+dfsg.orig.tar.xz: qt-creator-opensource-src-3.5.1+dfsg/src/plugins/qmakeprojectmanager/qmakeprojectconfigwidget.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMAKEPROJECTCONFIGWIDGET_H
#define QMAKEPROJECTCONFIGWIDGET_H

#include <projectexplorer/namedwidget.h>

QT_BEGIN_NAMESPACE
class QAbstractButton;
QT_END_NAMESPACE

namespace Utils { class DetailsWidget; }

namespace QmakeProjectManager {
class QmakeBuildConfiguration;
class QmakeProFileNode;

namespace Internal {
namespace Ui { class QmakeProjectConfigWidget; }

class QmakeProjectConfigWidget : public ProjectExplorer::NamedWidget
{
    Q_OBJECT
public:
    QmakeProjectConfigWidget(QmakeBuildConfiguration *bc);
    ~QmakeProjectConfigWidget();

private slots:
    // User changes in our widgets
    void shadowBuildClicked(bool checked);
    void onBeforeBeforeShadowBuildDirBrowsed();
    void shadowBuildEdited();

    // Changes triggered from creator
    void buildDirectoryChanged();
    void updateProblemLabel();
    void environmentChanged();

private:
    void updateDetails();
    void setProblemLabel(const QString &text);

    Ui::QmakeProjectConfigWidget *m_ui;
    QAbstractButton *m_browseButton;
    QmakeBuildConfiguration *m_buildConfiguration;
    Utils::DetailsWidget *m_detailsContainer;
    QString m_defaultShadowBuildDir;
    bool m_ignoreChange = false;
};

} // namespace Internal
} // namespace QmakeProjectManager

#endif // QMAKEPROJECTCONFIGWIDGET_H

==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/plugins/qmakeprojectmanager/qmakeprojectconfigwidget.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <projectexplorer/namedwidget.h>

QT_BEGIN_NAMESPACE
class QAbstractButton;
QT_END_NAMESPACE

namespace Utils { class DetailsWidget; }

namespace QmakeProjectManager {
class QmakeBuildConfiguration;

namespace Internal {
namespace Ui { class QmakeProjectConfigWidget; }

class QmakeProjectConfigWidget : public ProjectExplorer::NamedWidget
{
    Q_OBJECT
public:
    QmakeProjectConfigWidget(QmakeBuildConfiguration *bc);
    ~QmakeProjectConfigWidget();

private:
    // User changes in our widgets
    void shadowBuildClicked(bool checked);
    void onBeforeBeforeShadowBuildDirBrowsed();
    void shadowBuildEdited();

    // Changes triggered from creator
    void buildDirectoryChanged();
    void updateProblemLabel();
    void environmentChanged();

    void updateDetails();
    void setProblemLabel(const QString &text);

    Ui::QmakeProjectConfigWidget *m_ui;
    QAbstractButton *m_browseButton;
    QmakeBuildConfiguration *m_buildConfiguration;
    Utils::DetailsWidget *m_detailsContainer;
    QString m_defaultShadowBuildDir;
    bool m_ignoreChange = false;
};

} // namespace Internal
} // namespace QmakeProjectManager
